# This file was auto-generated by Fern from our API Definition.

import typing

CreateGeospatialStaticApiV1DashboardDatasetsGeospatialStaticPostRequestGeometryType = typing.Union[
    typing.Literal["point", "line", "polygon"], typing.Any
]
